@@ -98,7 +98,7 @@ Parameters::Parameters(
     validated        ( false ),
 
     // Instantiate Version
-    version( 1, 14, 0, "2023-01-07" )
+    version( 1, 14, 3, "2023-07-05" )
 {
     // Constructor code
     if ( method != Method::None ) {
@@ -130,11 +130,6 @@ void Parameters::Validate() {
                             "tau must be non-zero.\n" );
         throw std::runtime_error( errMsg );
     }
-    if ( tau > 0 ) {
-        std::string errMsg( "WARNING: Parameters::Validate(): "
-                            "Positive tau is experimental.\n" );
-        std::cout << errMsg;
-    }
 
     //--------------------------------------------------------------
     // Convert multi argument parameters from string to vectors
